# HUAWEI-SOLAR-TOOLS EN DESARROLLO

Este paquete permite interactuar con dispositivos Huawei Solar (inversores, baterías, medidores, etc.) utilizando Modbus. 

## Instalación
```bash
pip install huawei-solar-tools
```

